==> huaweicloudsdkgaussdb-3.1.100-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/restart_starrocks_node_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RestartStarrocksNodeRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'starrocks_node_id': 'str',
        'starrocks_instance_id': 'str',
        'x_language': 'str'
    }

    attribute_map = {
        'starrocks_node_id': 'starrocks_node_id',
        'starrocks_instance_id': 'starrocks_instance_id',
        'x_language': 'X-Language'
    }

    def __init__(self, starrocks_node_id=None, starrocks_instance_id=None, x_language=None):
        """RestartStarrocksNodeRequest

        The model defined in huaweicloud sdk

        :param starrocks_node_id: StarRocks节点ID
        :type starrocks_node_id: str
        :param starrocks_instance_id: StarRocks实例ID，严格匹配UUID规则。
        :type starrocks_instance_id: str
        :param x_language: 请求语言类型。默认en-us。 取值范围： - en-us - zh-cn
        :type x_language: str
        """
        
        

        self._starrocks_node_id = None
        self._starrocks_instance_id = None
        self._x_language = None
        self.discriminator = None

        self.starrocks_node_id = starrocks_node_id
        self.starrocks_instance_id = starrocks_instance_id
        if x_language is not None:
            self.x_language = x_language

    @property
    def starrocks_node_id(self):
        """Gets the starrocks_node_id of this RestartStarrocksNodeRequest.

        StarRocks节点ID

        :return: The starrocks_node_id of this RestartStarrocksNodeRequest.
        :rtype: str
        """
        return self._starrocks_node_id

    @starrocks_node_id.setter
    def starrocks_node_id(self, starrocks_node_id):
        """Sets the starrocks_node_id of this RestartStarrocksNodeRequest.

        StarRocks节点ID

        :param starrocks_node_id: The starrocks_node_id of this RestartStarrocksNodeRequest.
        :type starrocks_node_id: str
        """
        self._starrocks_node_id = starrocks_node_id

    @property
    def starrocks_instance_id(self):
        """Gets the starrocks_instance_id of this RestartStarrocksNodeRequest.

        StarRocks实例ID，严格匹配UUID规则。

        :return: The starrocks_instance_id of this RestartStarrocksNodeRequest.
        :rtype: str
        """
        return self._starrocks_instance_id

    @starrocks_instance_id.setter
    def starrocks_instance_id(self, starrocks_instance_id):
        """Sets the starrocks_instance_id of this RestartStarrocksNodeRequest.

        StarRocks实例ID，严格匹配UUID规则。

        :param starrocks_instance_id: The starrocks_instance_id of this RestartStarrocksNodeRequest.
        :type starrocks_instance_id: str
        """
        self._starrocks_instance_id = starrocks_instance_id

    @property
    def x_language(self):
        """Gets the x_language of this RestartStarrocksNodeRequest.

        请求语言类型。默认en-us。 取值范围： - en-us - zh-cn

        :return: The x_language of this RestartStarrocksNodeRequest.
        :rtype: str
        """
        return self._x_language

    @x_language.setter
    def x_language(self, x_language):
        """Sets the x_language of this RestartStarrocksNodeRequest.

        请求语言类型。默认en-us。 取值范围： - en-us - zh-cn

        :param x_language: The x_language of this RestartStarrocksNodeRequest.
        :type x_language: str
        """
        self._x_language = x_language

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RestartStarrocksNodeRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdb-3.1.158-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/restart_starrocks_node_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RestartStarrocksNodeRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'starrocks_node_id': 'str',
        'starrocks_instance_id': 'str',
        'x_language': 'str'
    }

    attribute_map = {
        'starrocks_node_id': 'starrocks_node_id',
        'starrocks_instance_id': 'starrocks_instance_id',
        'x_language': 'X-Language'
    }

    def __init__(self, starrocks_node_id=None, starrocks_instance_id=None, x_language=None):
        r"""RestartStarrocksNodeRequest

        The model defined in huaweicloud sdk

        :param starrocks_node_id: StarRocks节点ID
        :type starrocks_node_id: str
        :param starrocks_instance_id: StarRocks实例ID，严格匹配UUID规则。
        :type starrocks_instance_id: str
        :param x_language: 请求语言类型。默认en-us。 取值范围： - en-us - zh-cn
        :type x_language: str
        """
        
        

        self._starrocks_node_id = None
        self._starrocks_instance_id = None
        self._x_language = None
        self.discriminator = None

        self.starrocks_node_id = starrocks_node_id
        self.starrocks_instance_id = starrocks_instance_id
        if x_language is not None:
            self.x_language = x_language

    @property
    def starrocks_node_id(self):
        r"""Gets the starrocks_node_id of this RestartStarrocksNodeRequest.

        StarRocks节点ID

        :return: The starrocks_node_id of this RestartStarrocksNodeRequest.
        :rtype: str
        """
        return self._starrocks_node_id

    @starrocks_node_id.setter
    def starrocks_node_id(self, starrocks_node_id):
        r"""Sets the starrocks_node_id of this RestartStarrocksNodeRequest.

        StarRocks节点ID

        :param starrocks_node_id: The starrocks_node_id of this RestartStarrocksNodeRequest.
        :type starrocks_node_id: str
        """
        self._starrocks_node_id = starrocks_node_id

    @property
    def starrocks_instance_id(self):
        r"""Gets the starrocks_instance_id of this RestartStarrocksNodeRequest.

        StarRocks实例ID，严格匹配UUID规则。

        :return: The starrocks_instance_id of this RestartStarrocksNodeRequest.
        :rtype: str
        """
        return self._starrocks_instance_id

    @starrocks_instance_id.setter
    def starrocks_instance_id(self, starrocks_instance_id):
        r"""Sets the starrocks_instance_id of this RestartStarrocksNodeRequest.

        StarRocks实例ID，严格匹配UUID规则。

        :param starrocks_instance_id: The starrocks_instance_id of this RestartStarrocksNodeRequest.
        :type starrocks_instance_id: str
        """
        self._starrocks_instance_id = starrocks_instance_id

    @property
    def x_language(self):
        r"""Gets the x_language of this RestartStarrocksNodeRequest.

        请求语言类型。默认en-us。 取值范围： - en-us - zh-cn

        :return: The x_language of this RestartStarrocksNodeRequest.
        :rtype: str
        """
        return self._x_language

    @x_language.setter
    def x_language(self, x_language):
        r"""Sets the x_language of this RestartStarrocksNodeRequest.

        请求语言类型。默认en-us。 取值范围： - en-us - zh-cn

        :param x_language: The x_language of this RestartStarrocksNodeRequest.
        :type x_language: str
        """
        self._x_language = x_language

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RestartStarrocksNodeRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
